@@ -1,10 +1,11 @@
 # augs
 from .add_gaussian_noise_transform import AddGaussianNoiseTransform
 # base
-from .base.kd_compose_transform import KDComposeTransform
-from .base.kd_scheduled_transform import KDScheduledTransform
-from .base.kd_stochastic_transform import KDStochasticTransform
-from .base.kd_transform import KDTransform
+from .base import KDComposeTransform
+from .base import KDIdentityTransform
+from .base import KDScheduledTransform
+from .base import KDStochasticTransform
+from .base import KDTransform
 # augs
 from .image_pos_embed_grid import ImagePosEmbedGrid
 from .image_pos_embed_sincos import ImagePosEmbedSincos
